@@ -41,12 +41,13 @@
 
 class ComboBoxDelegate : public QStyledItemDelegate
 {
+
 public:
-    ComboBoxDelegate(QWidget *parent)
+    explicit ComboBoxDelegate(QWidget *parent)
         : QStyledItemDelegate(parent)
     {
     }
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         QStyleOptionViewItem &refToNonConstOption = const_cast<QStyleOptionViewItem &>(option);
         refToNonConstOption.showDecorationSelected = false;
@@ -160,8 +161,7 @@ LogViewFilterWidget::LogViewFilterWidget()
     QStandardItem *item = new QStandardItem(i18n("Select priorities"));
     item->setSelectable(false);
     d->prioritiesModel->appendRow(item);
-    connect(d->prioritiesModel, &QStandardItemModel::itemChanged,
-            this, &LogViewFilterWidget::prioritiesChanged);
+    connect(d->prioritiesModel, &QStandardItemModel::itemChanged, this, &LogViewFilterWidget::prioritiesChanged);
 
     // Don't add last enum value into combobox.
     for (int i = 0; i < metaEnum.keyCount() - 1; i++) {
@@ -197,7 +197,7 @@ void LogViewFilterWidget::initSearchListFilter()
     d->filterList->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
     connect(d->filterList, SIGNAL(activated(int)), d->filterLine, SLOT(setFocus()));
-    connect(d->filterList, SIGNAL(activated(int)), this, SLOT(changeColumnFilter(int)));
+    connect(d->filterList, QOverload<int>::of(&KComboBox::activated), this, &LogViewFilterWidget::changeColumnFilter);
     connect(d->filterList, SIGNAL(activated(int)), d->filterLine, SLOT(updateSearch()));
 }
 
